package com.huiju.welcome.controller;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.welcome.common.base.BaseController;
import com.huiju.welcome.common.base.ResponseBean;
import com.huiju.welcome.model.TaContentLib;
import com.huiju.welcome.service.ITaContentLibService;
import com.huiju.welcome.utils.StatusUtils;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.http.HttpStatus;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.time.LocalDateTime;

/**
 * <p>
 *  前端控制器
 * </p>
 *
 * @author jobob
 * @since 2019-03-12
 */
@RestController
@RequestMapping("/")
public class TaContentLibController extends BaseController {
    @Autowired
    private ITaContentLibService taContentLibService;

    @ApiOperation(value = "展示内容新增", notes = "展示内容新增")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataType = "String", name = "content", value = "内容值"),
            @ApiImplicitParam(paramType = "body", dataType = "String", name = "contentType", value = "内容类型")
    })
    @RequestMapping(value = "/content", method = RequestMethod.POST)
    public ResponseBean create(@RequestBody TaContentLib taContentLib, HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean();

        taContentLib.setStatus(StatusUtils.Normal);
        taContentLib.setCreateDate(LocalDateTime.now());

        boolean success = taContentLibService.save(taContentLib);
        if (!success) {
            responseBean.addError(HttpStatus.SC_INTERNAL_SERVER_ERROR, "新增内容失败, 请重试");
            return responseBean;
        }

        responseBean.addSuccess(taContentLib);
        return responseBean;
    }

    @ApiOperation(value = "展示内容删除", notes = "展示内容删除")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataType = "Integer", name = "id", value = "内容ID")
    })
    @RequestMapping(value = "/content/{id}", method = RequestMethod.DELETE)
    public ResponseBean delete(@PathVariable int id, HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean();

        TaContentLib taContentLib = taContentLibService.getById(id);
        taContentLib.setStatus(StatusUtils.Delete);

        boolean success = taContentLibService.updateById(taContentLib);
        if (!success) {
            responseBean.addError(HttpStatus.SC_INTERNAL_SERVER_ERROR, "删除内容失败, 请重试");
            return responseBean;
        }

        return responseBean;
    }

    @ApiOperation(value = "获取展示内容详情", notes = "获取展示内容详情")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataType = "Integer", name = "id", value = "内容ID")
    })
    @RequestMapping(value = "/content/{id}", method = RequestMethod.GET)
    public ResponseBean get(@PathVariable int id, HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean();

        TaContentLib taContentLib = taContentLibService.getById(id);
        if (null == taContentLib || taContentLib.getStatus().intValue() == StatusUtils.Delete) {
            responseBean.addError(HttpStatus.SC_BAD_REQUEST, "没有找到该ID对应数据");
            return responseBean;
        }

        responseBean.addSuccess(taContentLib);
        return responseBean;
    }


    @ApiOperation(value = "获取展示内容", notes = "获取展示内容")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "query", dataType = "int", name = "pageNum", value = "当前页"),
            @ApiImplicitParam(paramType = "query", dataType = "int", name = "pageSize", value = "每页数量"),
    })
    @RequestMapping(value = "/content", method = RequestMethod.GET)
    public ResponseBean list(@RequestParam Integer pageNum, @RequestParam  Integer pageSize, HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean();

        Page<TaContentLib> pg = new Page<>();
        pg.setCurrent(pageNum);
        pg.setSize(pageSize);
        QueryWrapper<TaContentLib> queryWrapper = new QueryWrapper<>();
        queryWrapper.orderByDesc("create_date");
        queryWrapper.eq("status", StatusUtils.Normal);
        responseBean.addSuccess(taContentLibService.page(pg, queryWrapper));

        return responseBean;
    }
}
