package com.huiju.welcome.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.welcome.common.base.BaseController;
import com.huiju.welcome.common.base.ResponseBean;
import com.huiju.welcome.model.TaPerson;
import com.huiju.welcome.model.TaVisitingLog;
import com.huiju.welcome.service.*;
import com.huiju.welcome.utils.StatusUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.http.HttpStatus;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 *  前端控制器
 * </p>
 *
 * @author jobob
 * @since 2019-03-12
 */
@RestController
@RequestMapping("/")
@Api(value = "人员管理API", description = "人员管理的API")
public class TaPersonController extends BaseController {
    @Autowired
    private ITaPersonService taPersonService;

    @Autowired
    private ITaVisitingLogService taVisitingLogService;
    
    @Autowired
    ITaDeviceService taDeviceService;

    @Autowired
    private ICameraService cameraService;

    @Autowired
    ITaCustomerService iTaCustomerService;

    @ApiOperation(value = "新增人员", notes = "新增人员")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataType = "TaPerson", name = "taPerson", value = "人员详情")
    })
    @RequestMapping(value = "/person", method = RequestMethod.POST)
    public ResponseBean create(@RequestBody TaPerson taPerson, HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean();

        taPerson.setStatus(StatusUtils.Normal);
        boolean success = taPersonService.save(taPerson);
        if (!success) {
            responseBean.addError(HttpStatus.SC_INTERNAL_SERVER_ERROR, "新增人员失败");
            return responseBean;
        }

        taPerson.setRealId(taPerson.getPersonId());
        success = taPersonService.updateById(taPerson);
        if (!success) {
            responseBean.addError(HttpStatus.SC_INTERNAL_SERVER_ERROR, "新增人员失败");
            return responseBean;
        }

        return responseBean;
    }

    @ApiOperation(value = "编辑人员", notes = "编辑人员")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataType = "TaPerson", name = "taPerson", value = "人员详情")
    })
    @RequestMapping(value = "/person", method = RequestMethod.PUT)
    public ResponseBean update(@RequestBody TaPerson taPerson, HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean();
        boolean success = taPersonService.updateById(taPerson);
        if (!success) {
            responseBean.addError(HttpStatus.SC_INTERNAL_SERVER_ERROR, "更新人员失败");
            return responseBean;
        }

        // 如果是将VIP更新为工作人员, 需要在客户列表中取消
        if (taPerson.getTypeId() == 2) {
            iTaCustomerService.deleteCustOfPerson(taPerson.getPersonId(), taPerson.getRealId());
        }

        return responseBean;
    }

    @ApiOperation(value = "合并人员", notes = "合并人员")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataType = "int", name = "from", value = "待合并人员ID"),
            @ApiImplicitParam(paramType = "body", dataType = "TaPerson", name = "to", value = "合并到人员ID")
    })
    @RequestMapping(value = "/merge/person/{from}", method = RequestMethod.PUT)
    public  ResponseBean merge(@PathVariable Integer from, @RequestBody TaPerson to) {
        ResponseBean responseBean = new ResponseBean();
        boolean success = taPersonService.mergePerson(from, to);
        if (!success) {
            responseBean.addError(HttpStatus.SC_INTERNAL_SERVER_ERROR, "合并人员失败");
            return responseBean;
        }

        return responseBean;
    }

    @ApiOperation(value = "更新人员头像", notes = "更新人员头像")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="path", dataType="Integer", name="personId", value="人员ID"),
            @ApiImplicitParam(paramType="path", dataType="Integer", name="logId", value="访问日志ID"
            )}
    )
    @RequestMapping(value = "/person/{personId}/log/{logId}", method = RequestMethod.PUT)
    public ResponseBean updateAvatar(@PathVariable int personId, @PathVariable int logId, HttpServletRequest request) throws Exception {
        ResponseBean responseBean = new ResponseBean();

        TaVisitingLog taVisitingLog = taVisitingLogService.getById(logId);

        TaPerson taPerson = new TaPerson();
        taPerson.setPersonId(personId);
        taPerson.setAvatar(taVisitingLog.getAvatar());

        String success = taPersonService.updateAvatar(taPerson);
        if (!success.equals("success")) {
            responseBean.addError(HttpStatus.SC_INTERNAL_SERVER_ERROR, success);
            return responseBean;
        }
        return responseBean;
    }

    @ApiOperation(value = "下发人员数据", notes = "下发人员数据")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="path", dataType="Integer", name="personId", value="人员ID"),
    })
    @RequestMapping(value = "/person/{personId}/avatar", method = RequestMethod.PUT)
    public ResponseBean DispatchProfile(@PathVariable int personId, HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean();
        TaPerson taPerson = taPersonService.getById(personId);
        String result = cameraService.dispatchPerson(taPerson);
        boolean success = null == result || "".equals(result) || "success".equals(result);
        if (!success) {
            responseBean.addError(HttpStatus.SC_INTERNAL_SERVER_ERROR, result);
            return responseBean;
        }
        return responseBean;
    }

	@ApiOperation(value = "获取人员详情", notes = "获取人员详情")
	@ApiImplicitParams({
			@ApiImplicitParam(paramType = "path", dataType = "Integer", name = "id", value = "人员ID")
	})
	@RequestMapping(value = "/person/{id}", method = RequestMethod.GET)
	public ResponseBean get(@PathVariable int id, HttpServletRequest request) {
		ResponseBean responseBean = new ResponseBean();

//		Map<String, Object> res = taPersonService.detail(id);
        Map<String, Object> res = new HashMap<>();
        res.put("detail", taPersonService.getById(id));

		responseBean.addSuccess(res);
		return responseBean;
	}

    @ApiOperation(value = "获取人员列表", notes = "获取人员列表")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "query", dataType = "int", name = "pageNum", value = "当前页"),
            @ApiImplicitParam(paramType = "query", dataType = "int", name = "pageSize", value = "每页数量"),
            @ApiImplicitParam(paramType = "query", dataType = "int", name = "typeId", value = "类型"),
            @ApiImplicitParam(paramType = "query", dataType = "int", name = "personId", value = "人员ID"),
            @ApiImplicitParam(paramType = "query", dataType = "String", name = "name", value = "姓名"),
            @ApiImplicitParam(paramType = "query", dataType = "String", name = "phone", value = "电话"),
            @ApiImplicitParam(paramType = "query", dataType = "String", name = "beginDate", value = "起始日期"),
            @ApiImplicitParam(paramType = "query", dataType = "String", name = "endDate", value = "结束日期"),
    })
    @RequestMapping(value = "/person", method = RequestMethod.GET)
    public ResponseBean list(
            @RequestParam Integer pageNum,
            @RequestParam  Integer pageSize,
            Integer typeId,
            Integer personId,
            String name,
            String phone,
            String beginDate,
            String endDate,
            HttpServletRequest request
    ) {
        ResponseBean responseBean = new ResponseBean();

        Page<TaPerson> page = new Page<>(pageNum, pageSize);

        if (null != typeId && typeId < 1) typeId = null;
        if (null != personId && personId < 1) personId = null;
        if (null != name && "".equals(name)) name = null;
        if (null != phone && "".equals(phone)) phone = null;
        if (null != beginDate && "".equals(beginDate)) beginDate = null;
        if (null != endDate && "".equals(endDate)) endDate = null;

        responseBean.addSuccess(taPersonService.getRealPersonList(page, personId, typeId, name, phone, beginDate, endDate));

        return responseBean;
    }

    @ApiOperation(value = "统计人员", notes = "统计人员")
    @RequestMapping(value = "/stats/person", method = RequestMethod.GET)
    public ResponseBean statsPerson() {
        ResponseBean responseBean = new ResponseBean();

        List<Map<String, String>> person = taPersonService.statsPerson();
        if (null == person) {
            person = new ArrayList<>();
        }
        if (person.size() == 0) {
            Map<String, String> mp = new HashMap<>();
            person.add(mp);
        }

        Long regularClients = taVisitingLogService.getRegularClientTodayAmount();
        if (null ==  regularClients) regularClients = 0l;

        person.get(0).put("regular", String.valueOf(regularClients));

        responseBean.addSuccess(person);
        return responseBean;
    }
}
